searchData={"items":[{"type":"module","title":"PhoenixStatic.Actions","doc":"","ref":"PhoenixStatic.Actions.html"},{"type":"module","title":"PhoenixStatic.Dependencies","doc":"Conveniences for working with dependencies.\n\nIn this module, \"older\" means \"needs recompiling when considering...\".\nSo, if we compare a first module to a module that doesn't exist,\nthe first module doesn't need recompiling, so it's not \"older\".","ref":"PhoenixStatic.Dependencies.html"},{"type":"function","title":"PhoenixStatic.Dependencies.module_last_modified/1","doc":"","ref":"PhoenixStatic.Dependencies.html#module_last_modified/1"},{"type":"function","title":"PhoenixStatic.Dependencies.older_than_module?/2","doc":"","ref":"PhoenixStatic.Dependencies.html#older_than_module?/2"},{"type":"function","title":"PhoenixStatic.Dependencies.older_than_unix_timestamp?/2","doc":"","ref":"PhoenixStatic.Dependencies.html#older_than_unix_timestamp?/2"},{"type":"module","title":"PhoenixStatic.Page","doc":"This module defines the information structure used to build static pages.","ref":"PhoenixStatic.Page.html"},{"type":"type","title":"PhoenixStatic.Page.t/0","doc":"","ref":"PhoenixStatic.Page.html#t:t/0"},{"type":"module","title":"PhoenixStatic.Routes","doc":"","ref":"PhoenixStatic.Routes.html"},{"type":"behaviour","title":"PhoenixStatic.Source","doc":"Defines a behaviour for modules that can be used as a source of static routes.","ref":"PhoenixStatic.Source.html"},{"type":"callback","title":"PhoenixStatic.Source.last_modified/0","doc":"Returns the last modified timestamp of the source.\n\nThe return value is a UNIX timestamp.\n\nNote, the granularity of the timestamp comparisons is one second.\n\nThis function is called by the HTML view to determine\nwhether the source has changed since the last compilation of the module.\nIf the source has changed, the view, along with the related controller and\nthe project's router module, will be recompiled.\n\nThis function should be as fast, reliable and lightweight as possible as it\nis called on each compilation. Above all, in development mode, it will\nbe called on each request.","ref":"PhoenixStatic.Source.html#c:last_modified/0"},{"type":"callback","title":"PhoenixStatic.Source.list_pages/0","doc":"Returns the content, path and other information for all static pages.","ref":"PhoenixStatic.Source.html#c:list_pages/0"},{"type":"module","title":"PhoenixStatic.Views","doc":"","ref":"PhoenixStatic.Views.html"},{"type":"function","title":"PhoenixStatic.Views.content_last_modified/0","doc":"","ref":"PhoenixStatic.Views.html#content_last_modified/0"},{"type":"extras","title":"PhoenixStatic","doc":"# PhoenixStatic\n\n![Version](https://img.shields.io/hexpm/v/phoenix_static)\n\nBuild static pages into a Phoenix application at compile time.\n\n# About\n\nThis library is designed to be used in a Phoenix application to generate static pages at compile time.\n\nIt is useful in cases where you have content hosted elsewhere (e.g. a CMS) and want to generate static pages for performance reasons.\n\n# Configuration\n\nTo use this library, you need to add it to your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:phoenix_static, \"~> (see the badge above)\"}\n  ]\nend\n```\n\nThen you need to implement the `PhoenixStatic.Source` behaviour in a module.\nThis module will be responsible for fetching the content and providing the last modification date.\n\n```elixir\ndefmodule MyAppWeb.Static do\n  @behaviour PhoenixStatic.Source\n\n  @impl true\n  def list_pages() do\n    # Fetch content from your CMS or other source\n    {:ok, content}\n  end\n\n  @impl true\n  def last_modified() do\n    # Return the last modification time of the content\n    {:ok, last_modified_time}\n  end\nend\n```\n\nNow, inject the static pages into the router, a Controller and its HTML View:\n\n```elixir\ndefmodule MyAppWeb.Router do\n  ...\n  use PhoenixStatic.Routes, pipelines: [:browser]\n  ...\nend\n\ndefmodule MyAppWeb.MyPageController do\n  use MyAppWeb, :controller\n  use PhoenixStatic.Actions\n\n  ...\nend\n\ndefmodule MyAppWeb.MyPageHTML do\n  use MyAppWeb, :html\n  use PhoenixStatic.Views\n\n  ...\nend\n```\n\nThen, you need to configure it in your `config/config.exs` file:\n\n```elixir\nconfig :phoenix_static,\n  source: MyAppWeb.Static,\n  controller: MyAppWeb.MyPageController,\n  view: MyAppWeb.MyPageHTML\n```\n\n# Further Information\n\nAll page content is currently held in memory during compilation, so it is not\nsuitable for large amounts of data.\n\nThe data is saved in the HTML view module, and is available via the\n`__phoenix_static_pages__/1` function.","ref":"readme.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}